@@ -5,9 +5,11 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+
 class GroupedData:
     pass
 
+
 class GroupedStream:
     def __init__(self, stream):
         self._stream = stream
@@ -15,9 +17,11 @@ class GroupedStream:
     def __iter__(self):
         return iter(self._stream)
 
-class GroupedDict:
+
+class GroupedDict(dict):
     pass
 
+
 class ChromosomeProvider:
     """Base class for objects that can provide data grouped by chromosomes, 
     either by supplying a stream of `(chromosome_name, data)` tuples, or by
