@@ -1,4 +1,5 @@
 import numpy as np
+from typing import List
 from .encodings import QualityEncoding
 from .encodings.base_encoding import CigarEncoding
 from .encodings.alphabet_encoding import CigarOpArray, BamArray
@@ -38,8 +39,13 @@ class Bed6(Interval):
 
 
 @bnpdataclass
-class StrandedInterval(Interval):
-    strand: int
+class Bed12(Bed6):
+    thick_start: int
+    thick_end: int
+    item_rgb: str
+    block_count: int
+    block_sizes: List[int]
+    block_starts: List[int]
 
 
 @bnpdataclass
@@ -50,6 +56,18 @@ class Variant:
     alt_seq: str
 
 
+@bnpdataclass
+class VCFEntry:
+    chromosome: str
+    position: int(-1)
+    id: str
+    ref_seq: str
+    alt_seq: str
+    # quality: int
+    # filter: str
+    # info: str
+
+
 @bnpdataclass
 class VariantWithGenotypes(Variant):
     genotypes: int
@@ -118,3 +136,9 @@ class BamEntry:
     cigar_length: CigarEncoding
     sequence: BamArray
     quality: QualityEncoding
+
+
+@bnpdataclass
+class ChromosomeSize:
+    name: str
+    size: int
