@@ -1,18 +1,18 @@
 import numpy as np
 from .base_encoding import Encoding
-from ..sequences import EncodedArray
+from ..sequences import ASCIIText, EncodedArray
 
 
 class AlphabetEncoding(Encoding):
     def __init__(self, alphabet: str):
         alphabet = [c.lower() for c in alphabet]
         self._alphabet = np.array([ord(c) for c in alphabet], dtype=np.uint8)
-        upper_alphabet = (self._alphabet + ord("A")-ord("a")).view(EncodedArray)
-        self._alphabet = self._alphabet.view(EncodedArray)
-        self._lookup = np.zeros(256, dtype=np.uint8).view(EncodedArray)
+        upper_alphabet = (self._alphabet + ord("A")-ord("a")).view(ASCIIText)
+        self._alphabet = self._alphabet.view(ASCIIText)
+        self._lookup = np.zeros(256, dtype=np.uint8)
         self._lookup[self._alphabet] = np.arange(len(alphabet))
         self._lookup[upper_alphabet] = np.arange(len(alphabet))
-        self._lookup.encoding = self
+        # self._lookup.encoding = self
         self._mask = np.zeros(256, dtype=bool)
         self._mask[self._alphabet] = True
         self._mask[upper_alphabet] = True
@@ -57,3 +57,4 @@ RNAArray = get_alphabet_array_class("ACUG")
 AminoAcidArray = get_alphabet_array_class('ACDEFGHIKLMNPQRSTVWY')
 BamArray = get_alphabet_array_class("=ACMGRSVTWYHKDBN")
 CigarOpArray = get_alphabet_array_class("MIDNSHP=X")
+DigitArray = get_alphabet_array_class("0123456789")
