@@ -1,4 +1,5 @@
 from abc import abstractmethod
+import numpy as np
 
 
 class Encoding:
@@ -20,4 +21,18 @@ class ASCIIEncoding(Encoding):
         return encoded
 
 
+class NumericEncoding(Encoding):
+    pass
+
+
+class CigarEncoding(NumericEncoding):
+    @classmethod
+    def encode(cls, data):
+        return np.asarray(data)
+
+    @classmethod
+    def decode(cls, data):
+        return np.asarray(data)
+
+
 BaseEncoding = ASCIIEncoding()
