@@ -1,7 +1,7 @@
 import numpy as np
 from npstructures import RaggedArray, RaggedView, RaggedShape, npdataclass
 from .encodings import BaseEncoding, QualityEncoding
-from .sequences import EncodedArray, to_ascii, as_encoded_sequence_array
+from .sequences import to_ascii, ASCIIText, Sequences
 from .datatypes import SequenceEntry, SequenceEntryWithQuality
 
 NEWLINE = 10
@@ -26,7 +26,7 @@ class FileBuffer:
     COMMENT = 0
 
     def __init__(self, data, new_lines):
-        self._data = np.asanyarray(data).view(EncodedArray)
+        self._data = np.asanyarray(data).view(ASCIIText)
         self._new_lines = np.asanyarray(new_lines)
         self._is_validated = False
         self.size = self._data.size
@@ -108,7 +108,7 @@ class FileBuffer:
         if lens is None:
             lens = ends - starts
         indices, shape = RaggedView(starts, lens).get_flat_indices()
-        return RaggedArray(self._data[indices], shape)
+        return Sequences(self._data[indices], shape)
 
     def _move_2d_array_to_intervals(self, array, starts, ends):
         n_chars = ends - starts
@@ -157,7 +157,7 @@ class OneLineBuffer(FileBuffer):
         indices, shape = RaggedView(sequence_starts, sequence_lens).get_flat_indices()
         m = indices.size
         d = m % self._buffer_divisor
-        seq = np.empty(m - d + self._buffer_divisor, dtype=self._data.dtype).view(EncodedArray)
+        seq = np.empty(m - d + self._buffer_divisor, dtype=self._data.dtype).view(ASCIIText)
         seq[:m] = self._data[indices]
         return RaggedArray(seq, shape)
 
@@ -170,6 +170,9 @@ class OneLineBuffer(FileBuffer):
         headers = self.lines[:: self.n_lines_per_entry, 1:-1]
         return SequenceEntry(headers, sequences)
 
+    def count_entries(self):
+        return len(self._new_lines)//self.n_lines_per_entry
+
     @classmethod
     def from_data(cls, entries):
         name_lengths = entries.name.shape.lengths
@@ -177,15 +180,15 @@ class OneLineBuffer(FileBuffer):
         line_lengths = np.hstack(
             (name_lengths[:, None] + 2, sequence_lengths[:, None] + 1)
         ).ravel()
-        buf = np.empty(line_lengths.sum(), dtype=np.uint8).view(EncodedArray)
+        buf = np.empty(line_lengths.sum(), dtype=np.uint8).view(ASCIIText)
         lines = RaggedArray(buf, line_lengths)
         step = cls.n_lines_per_entry
         lines[0::step, 1:-1] = entries.name
         lines[1::step, :-1] = entries.sequence
 
-        lines[0::step, 0] = ord(">")
+        lines[0::step, 0] = ">"
 
-        lines[:, -1] = ord("\n")
+        lines[:, -1] = "\n"
         return buf
 
     def _validate(self):
@@ -207,14 +210,15 @@ class TwoLineFastaBuffer(OneLineBuffer):
 
 
 class FastQBuffer(OneLineBuffer):
-    HEADER = ord("@")
+    HEADER = "@"
     n_lines_per_entry = 4
     dataclass = SequenceEntryWithQuality
 
     def get_data(self):
         seq_entry = super().get_data()
         quality = self.lines[3 :: self.n_lines_per_entry, :-1]
-        return SequenceEntryWithQuality(seq_entry.name, seq_entry.sequence, quality)
+        return SequenceEntryWithQuality(
+            seq_entry.name, seq_entry.sequence, quality)
 
     @classmethod
     def _get_line_lens(cls, entries):
@@ -235,14 +239,14 @@ class FastQBuffer(OneLineBuffer):
     @classmethod
     def from_data(cls, entries):
         line_lengths = cls._get_line_lens(entries)
-        buf = np.empty(line_lengths.sum(), dtype=np.uint8).view(EncodedArray)
+        buf = np.empty(line_lengths.sum(), dtype=np.uint8).view(ASCIIText)
         lines = RaggedArray(buf, line_lengths)
         step = cls.n_lines_per_entry
         lines[0::step, 1:-1] = entries.name
         lines[1::step, :-1] = entries.sequence
-        lines[2::step, 0] = ord("+")
+        lines[2::step, 0] = "+"
         lines[3::step, :-1] = to_ascii(entries.quality, QualityEncoding)
         lines[0::step, 0] = cls.HEADER
-        lines[:, -1] = ord("\n")
+        lines[:, -1] = "\n"
 
         return buf
