@@ -6,11 +6,15 @@ from .file_buffers import (TwoLineFastaBuffer, FastQBuffer)
 from .multiline_buffer import MultiLineFastaBuffer
 from .bam import BamBuffer
 from .delimited_buffers import (VCFBuffer, BedBuffer, GfaSequenceBuffer, get_bufferclass_for_datatype)
-from .datatypes import GFFEntry, SAMEntry
+from .datatypes import GFFEntry, SAMEntry, ChromosomeSize
 from .parser import NumpyFileReader, NpBufferedWriter, chunk_lines
 from .chromosome_provider import FullChromosomeDictProvider, ChromosomeFileStreamProvider, LazyChromosomeDictProvider
 from .indexed_fasta import IndexedFasta
 from .npdataclassstream import NpDataclassStream
+import logging
+
+logger = logging.getLogger(__name__)
+# from .gzip import gzip
 
 
 class NpDataclassReader:
@@ -55,7 +59,8 @@ buffer_types = {
     ".gtf": get_bufferclass_for_datatype(GFFEntry),
     ".gff3": get_bufferclass_for_datatype(GFFEntry),
     ".sam": get_bufferclass_for_datatype(SAMEntry, comment="@"),
-    ".bam": BamBuffer
+    ".bam": BamBuffer,
+    ".sizes": get_bufferclass_for_datatype(ChromosomeSize)
 }
 
 
@@ -70,6 +75,8 @@ def _get_buffered_file(
 
     kwargs2 = {key: val for key, val in kwargs.items() if key in ["has_header"]}
     file_reader = NumpyFileReader(open_func(filename, "rb"), buffer_type, **kwargs2)
+    if is_gzip:
+        file_reader.set_prepend_mode()
     return NpDataclassReader(file_reader)
 
 
@@ -92,3 +99,21 @@ def bnp_open(filename, mode=None, **kwargs):
         assert mode not in ("w", "write", "wb")
         return IndexedFasta(filename[:-4], **kwargs)
     return _get_buffered_file(filename, suffix, mode, is_gzip=is_gzip, **kwargs)
+
+
+def count_entries(filename, buffer_type=None):
+    logger.info(f"Counting entries in {filename}")
+    path = PurePath(filename)
+    suffix = path.suffixes[-1]
+    is_gzip = suffix in (".gz", ".bam")
+    if suffix == ".gz":
+        suffix = path.suffixes[-2]
+    open_func = gzip.open if is_gzip else open
+    if buffer_type is None:
+        buffer_type = _get_buffer_type(suffix)
+
+    file_reader = NumpyFileReader(open_func(filename, "rb"), buffer_type)
+    if is_gzip:
+        file_reader.set_prepend_mode()
+    chunk_counts = (chunk.count_entries() for chunk in file_reader.read_chunks())
+    return sum(chunk_counts)
