@@ -55,7 +55,8 @@ class NumpyFileReader:
         self._remove_initial_comments()
         self._header_data = self._buffer_type.read_header(self._file_obj)
         self._total_bytes_read = 0
-
+        self._do_prepend = False
+        self._prepend = []
 
     def __enter__(self):
         return self
@@ -66,6 +67,9 @@ class NumpyFileReader:
     def __iter__(self):
         return self.read_chunks()
 
+    def set_prepend_mode(self):
+        self._do_prepend = True
+
     def read(self):
         # self._remove_initial_comments()
         # self._header_data = self._buffer_type.read_header(self._file_obj)
@@ -77,12 +81,17 @@ class NumpyFileReader:
         chunk = self.__get_buffer(chunk_size)
         if chunk is None:
             return None
+        if len(self._prepend):
+            chunk = np.concatenate((self._prepend, chunk))
+            self._prepend = []
 
         self._total_bytes_read += chunk.size
         buff = self._buffer_type.from_raw_buffer(chunk, header_data=self._header_data)
         if not self._is_finished:
-            self._file_obj.seek(buff.size - chunk_size, 1)
-
+            if not self._do_prepend:
+                self._file_obj.seek(buff.size - chunk.size, 1)
+            else:
+                self._prepend = chunk[buff.size:]
         if chunk is not None and chunk.size:
             return wrapper(buff)
 
@@ -97,7 +106,7 @@ class NumpyFileReader:
             chunk = np.append(chunk, np.uint8(ord("\n")))
             bytes_read += 1
         if hasattr(self._buffer_type, "_new_entry_marker"):
-            chunk = np.append(chunk, np.uint8(self._buffer_type._new_entry_marker))
+            chunk = np.append(chunk, np.uint8(ord(self._buffer_type._new_entry_marker)))
             bytes_read += 1
         return chunk, bytes_read
 
@@ -127,8 +136,11 @@ class NumpyFileReader:
     def _remove_initial_comments(self):
         if self._buffer_type.COMMENT == 0:
             return
+        comment = self._buffer_type.COMMENT
+        if isinstance(comment, str):
+            comment = ord(comment)
         for line in self._file_obj:
-            if line[0] != self._buffer_type.COMMENT:
+            if line[0] != comment:
                 self._file_obj.seek(-len(line), 1)
                 break
 
