@@ -1,7 +1,7 @@
 import pytest
 from bionumpy.file_buffers import FastQBuffer, TwoLineFastaBuffer
-from bionumpy.datatypes import SequenceEntry, SequenceEntryWithQuality, Interval, SNP, SAMEntry
-from bionumpy.delimited_buffers import BedBuffer, VCFBuffer, GfaSequenceBuffer
+from bionumpy.datatypes import SequenceEntry, SequenceEntryWithQuality, Interval, SNP, SAMEntry, VCFEntry, Bed12
+from bionumpy.delimited_buffers import BedBuffer, VCFBuffer, GfaSequenceBuffer, Bed12Buffer
 from bionumpy.multiline_buffer import MultiLineFastaBuffer
 from bionumpy.sequences import EncodedArray
 import numpy as np
@@ -39,7 +39,7 @@ TTT
     , "bed": """\
 chr1\t1\t3\t.\t.\t-
 chr1\t40\t60\t.\t.\t+
-chr2\t400\t600\t.\t.\t+
+chr20\t400\t600\t.\t.\t+
 """
     , "vcf": """\
 chr1	88362	rs4970378	A	G
@@ -70,6 +70,10 @@ CHROMOSOME_I	Allele	substitution	13721389	13721389	.	+.	aachange=A to V;conseque
 @SQ	SN:test_ref	LN:17637
 SRR1524970.144283	16	test_ref	1706	255	25M	*	0	0	TGCTGATGAAGCAGAACAACTTTAA	]YG[^baaaa^W`ab]]````aaba	AS:i:0	XN:i:0	XM:i:0	XO:i:0	XG:i:0	NM:i:0	MD:Z:25	YT:Z:UU
 SRR1524970.316478	16	test_ref	1706	255	24M	*	0	0	TGCTGATGAAGCAGAACAACTTTA	`\X_`aaaaaY]``b_aa_aaaaa	AS:i:0	XN:i:0	XM:i:0	XO:i:0	XG:i:0	NM:i:0	MD:Z:24	YT:Z:UU
+""",
+    "bed12": """\
+chr21 10079666  10120808   uc002yiv.1  0  -  10081686  10120608  0     4   528,91,101,215, 0,1930,39750,40927,
+chr21 10080031  10081687   uc002yiw.1  0  -  10080031  100800310\t0     2   200,91,    0,1565,
 """
 }
 
@@ -79,15 +83,15 @@ data = {
     "bed": [
         Interval.single_entry("chr1", 1, 3),
         Interval.single_entry("chr1", 40, 60),
-        Interval.single_entry("chr2",  400, 600)],
+        Interval.single_entry("chr20",  400, 600)],
     "vcf2": [
-        SNP.single_entry("chr1",	88361,	"A",	"G"),
-        SNP.single_entry("chr1",	887559,	"A",	"CAA"),
-        SNP.single_entry("chr2",	8877,	"AGG",	"C")],
+        VCFEntry.single_entry("chr1",	88361, "rs4970378",	"A",	"G"),
+        VCFEntry.single_entry("chr1",	887559, "rs3748595",	"A",	"CAA"),
+        VCFEntry.single_entry("chr2",	8877, "rs3828047",	"AGG",	"C")],
     "vcf": [
-        SNP.single_entry("chr1",	88361,	"A",	"G"),
-        SNP.single_entry("chr1",	887559,	"A",	"C"),
-        SNP.single_entry("chr2",	8877,	"A",	"G")],
+        VCFEntry.single_entry("chr1",	88361, "rs4970378",	"A",	"G"),
+        VCFEntry.single_entry("chr1",	887559, "rs3748595",	"A",	"C"),
+        VCFEntry.single_entry("chr2",	8877, "rs3828047",	"A",	"G")],
     "fastq": [
         SequenceEntryWithQuality.single_entry("headerishere", "CTTGTTGA", "".join("!" for _ in "CTTGTTGA")),
         SequenceEntryWithQuality.single_entry("anotherheader", "CGG", "".join("~" for _ in "CGG"))],
@@ -102,7 +106,10 @@ data = {
         SequenceEntry.single_entry("id4", "ACTG")],
     "sam": [
         SAMEntry.single_entry("SRR1524970.144283", 16, "test_ref", 1705, 255, "25M",	"*", 0, 0, "TGCTGATGAAGCAGAACAACTTTAA", "]YG[^baaaa^W`ab]]````aaba"),
-        SAMEntry.single_entry("SRR1524970.316478", 16, "test_ref", 1705, 255, "24M", "*", 0, 0, "TGCTGATGAAGCAGAACAACTTTA", 	"`\X_`aaaaaY]``b_aa_aaaaa")]
+        SAMEntry.single_entry("SRR1524970.316478", 16, "test_ref", 1705, 255, "24M", "*", 0, 0, "TGCTGATGAAGCAGAACAACTTTA", 	"`\X_`aaaaaY]``b_aa_aaaaa")],
+    "bed12": [
+        Bed12.single_entry("chr21", 10079666,  10120808,   "uc002yiv.1", 0, "-", 10081686, 10120608,  "0",     4,   [[528,91,101,215]], [[0,1930,39750,40927]]),
+        Bed12.single_entry("chr21", 10080031,  10081687,   "uc002yiw.1",  0,  "-",  10080031,  10080031,  "0",     2,   [[200,91]],    [[0,1565]])]
 }
 
 
@@ -112,7 +119,9 @@ buffer_type = {"bed": BedBuffer,
                "fastq": FastQBuffer,
                "fasta": TwoLineFastaBuffer,
                "gfa_sequence": GfaSequenceBuffer,
-               "multiline_fasta": MultiLineFastaBuffer}
+               "multiline_fasta": MultiLineFastaBuffer,
+               "bed12": Bed12Buffer}
+
 
 combos = {key: (buffers[key], data[key], buffer_type[key]) for key in buffer_type}
 
