@@ -1,34 +1,35 @@
 from bionumpy.minimizers import Minimizers
-from bionumpy.sequences import Sequences, Sequence
+from bionumpy.sequences import Sequence
 from bionumpy.kmers import KmerEncoding
-from bionumpy.encodings import ACTGEncoding
+from bionumpy.encodings.alphabet_encoding import DNAArray
+from npstructures import RaggedArray
 import numpy as np
 import pytest
 
 
 @pytest.fixture
 def sequence():
-    return np.array([0, 3, 1, 2, 2, 1, 0])
+    return np.array([0, 3, 1, 2, 2, 1, 0]).view(DNAArray)
 
 
 @pytest.fixture
 def sequences():
-    return Sequences([[0, 3, 1, 2, 2, 1, 0],
-                      [0, 3, 1, 2, 2, 1],
-                      [0, 3, 1, 2, 2],
-                      [0, 3, 1, 2]], encoding=ACTGEncoding)
+    r = RaggedArray([[0, 3, 1, 2, 2, 1, 0],
+                     [0, 3, 1, 2, 2, 1],
+                     [0, 3, 1, 2, 2],
+                     [0, 3, 1, 2]])
+    r._data = r._data.view(DNAArray)
+    return r
 
 
 @pytest.fixture
 def window():
-    s = Sequence.from_array(np.array([0, 3, 1, 2]))
-    s.encoding = ACTGEncoding
-    return s
+    return np.array([0, 3, 1, 2]).view(DNAArray)
 
 
 @pytest.fixture
 def encoding():
-    return Minimizers(3, KmerEncoding(2, alphabet_size=4))
+    return Minimizers(3, KmerEncoding(2, DNAArray))
 
 
 def test_window(window, encoding):
